pub struct SuperSegment {
pub header: SuperSegmentHeader,
pub segment_roots: Arc<[ShardSegmentRootWithPosition]>,
}Expand description
Super segment
Fields
header: SuperSegmentHeaderSuper segment root
segment_roots: Arc<[ShardSegmentRootWithPosition]>Segment roots that are included in the super segment
Implementations
Sourceimpl SuperSegment
impl SuperSegment
Sourcepub fn new(
previous_header: &SuperSegmentHeader,
target_beacon_chain_block_number: BlockNumber,
segment_roots: StdArc<[ShardSegmentRootWithPosition]>,
) -> Option<Self>
pub fn new( previous_header: &SuperSegmentHeader, target_beacon_chain_block_number: BlockNumber, segment_roots: StdArc<[ShardSegmentRootWithPosition]>, ) -> Option<Self>
Create a new instance and derive super segment root.
Returns None if the list of segment roots is empty or there are too many of them.
Sourcepub fn proof_for_segment(&self, segment_position: u32) -> Option<SegmentProof>
pub fn proof_for_segment(&self, segment_position: u32) -> Option<SegmentProof>
Produce a proof for a segment in the super segment at a given position