#[repr(C)]pub struct SuperSegmentHeader {
pub index: Unaligned<SuperSegmentIndex>,
pub root: SuperSegmentRoot,
pub prev_super_segment_header_hash: Blake3Hash,
pub max_segment_index: Unaligned<SegmentIndex>,
pub target_beacon_chain_block_number: Unaligned<BlockNumber>,
pub num_segments: u32,
}Expand description
Super segment header
Fields
index: Unaligned<SuperSegmentIndex>Super segment index
root: SuperSegmentRootSuper segment root
prev_super_segment_header_hash: Blake3HashHash of the previous super segment header
max_segment_index: Unaligned<SegmentIndex>Max index of the segment in the super segment
target_beacon_chain_block_number: Unaligned<BlockNumber>Target beacon chain block number for the super segment
num_segments: u32Number of segments in the super segment